pub enum TestPlanStepAction {
Increasing,
Maintaining,
Decreasing,
Canceling,
Finished,
}Expand description
A test plan is a series of steps performing one of the following actions.
Variants
Increasing
A test plan step that is increasing the number of GooseUser threads.
Maintaining
A test plan step that is maintaining the number of GooseUser threads.
Decreasing
A test plan step that is decreasing the number of GooseUser threads.
Canceling
A test plan step that is canceling all GooseUser threads.
Finished
The final step indicating that the load test is finished.